@@ -69,8 +69,15 @@ class SciNoteClient(object):
         )
         self.update_token(token)
 
-    def update_token(self, token):
+    def update_token(self, name, token, refresh_token=None, access_token=None):
         """Update token and save it."""
+        if refresh_token:
+            item = token.find(name=name, refresh_token=refresh_token)
+        elif access_token:
+            item = token.find(name=name, access_token=access_token)
+        else:
+            return
+
         self.access_token = token["access_token"]
         self.refresh_token = token["refresh_token"]
         self.token = token
@@ -82,7 +89,7 @@ class SciNoteClient(object):
             client_id=self.client_id,
             client_secret=self.client_secret,
             token=self.token,
-            update_token=self.refresh_access_token,
+            update_token=self.update_token,
         ) as client:
             return client.request(method, url, json=json)
 
